summaryrefslogtreecommitdiffstats
path: root/kded/kbuildsycoca.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kded/kbuildsycoca.cpp')
-rw-r--r--kded/kbuildsycoca.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kded/kbuildsycoca.cpp b/kded/kbuildsycoca.cpp
index 041c9db3a..30b826c8c 100644
--- a/kded/kbuildsycoca.cpp
+++ b/kded/kbuildsycoca.cpp
@@ -717,7 +717,7 @@ public:
extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
{
- KLocale::setMainCatalogue("kdelibs");
+ KLocale::setMainCatalogue("tdelibs");
KAboutData d(appName, I18N_NOOP("KBuildSycoca"), appVersion,
I18N_NOOP("Rebuilds the system configuration cache."),
KAboutData::License_GPL, "(c) 1999-2002 KDE Developers");
@@ -763,8 +763,8 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
KCrash::setEmergencySaveFunction(crashHandler);
KCrash::setApplicationName(TQString(appName));
- // this program is in kdelibs so it uses kdelibs as catalog
- KLocale::setMainCatalogue("kdelibs");
+ // this program is in tdelibs so it uses tdelibs as catalog
+ KLocale::setMainCatalogue("tdelibs");
// force generating of KLocale object. if not, the database will get
// be translated
KGlobal::locale();